##  Step 3: Import and Link Tech Categories
Import tech categories relevant to your organization from the reference catalog.
Follow these steps:
  1. In the Reference Catalog section of the administration area, go to the Tech Category tab.
  2. Under Import TBM Taxonomy, choose Import TBM.
  3. Select tech categories for import. Make sure to select the tech categories you renamed in the previous step:
     * Enabling Platforms and all its child tech categories
     * Tech Service Management
     * Technology Vendor Management
     * Tech Training
     * Domain Solutions
     * Planning & Management Accounting
     * Workspace Solutions
  4. Choose Import and Link.
